// Copyright 2011 Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// * Redistributions of source code must retain the above copyright
//   notice, this list of conditions and the following disclaimer.
// * Redistributions in binary form must reproduce the above copyright
//   notice, this list of conditions and the following disclaimer in the
//   documentation and/or other materials provided with the distribution.
// * Neither the name of Google Inc. nor the names of its contributors
//   may be used to endorse or promote products derived from this software
//   without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

/// \file engine/plain_iface/test_case.hpp
/// Provides the plain-specific test_case class and other auxiliary types.

#if !defined(ENGINE_PLAIN_IFACE_TEST_CASE_HPP)
#define ENGINE_PLAIN_IFACE_TEST_CASE_HPP

#include <string>

#include "engine/test_case.hpp"
#include "utils/config/tree.hpp"
#include "utils/fs/path.hpp"

namespace engine {
namespace plain_iface {


/// Representation of a plain test case.
class test_case : public base_test_case {
    properties_map get_all_properties(void) const;
    virtual test_result execute(
        const utils::config::tree&, test_case_hooks&,
        const utils::optional< utils::fs::path >&,
        const utils::optional< utils::fs::path >&) const;

public:
    test_case(const base_test_program&);
};


}  // namespace plain_iface
}  // namespace engine

#endif  // !defined(ENGINE_PLAIN_IFACE_TEST_CASE_HPP)
